import pickle

WORD = {
    'a' : [
        'a',
        'ability',
        'able',
        'about',
        'above',
        'abroad',
        'absolutely',
        'accept',
        'acceptable',
        'accident',
        'according to',
        'account',
        'accuse',
        'achieve',
        'acid',
        'across',
        'act',
        'action',
        'active',
        'activity',
        'actor',
        'actress',
        'actual',
        'actually',
        'ad',
        'add',
        'address',
        'admire',
        'admit',
        'adult',
        'advantage',
        'adventure',
        'advertisement',
        'advice',
        'advise',
        'affect',
        'afford',
        'afraid',
        'after',
        'afternoon',
        'afterwards',
        'again',
        'against',
        'age',
        'aged',
        'ago',
        'agree',
        'agreement',
        'ahead',
        'aim',
        'air',
        'aircraft',
        'airport',
        'alcohol',
        'alcoholic',
        'alive',
        'all',
        'allow',
        'all right',
        'almost',
        'alone',
        'along',
        'alphabet',
        'already',
        'also',
        'although',
        'always',
        'among',
        'amount',
        'amuse',
        'amusing',
        'an',
        'ancient',
        'anger',
        'angle',
        'angry',
        'animal',
        'announce',
        'annoy',
        'annoyed',
        'annoying',
        'another',
        'answer',
        'any',
        'anybody',
        'anyone',
        'anything',
        'anyway',
        'apart',
        'apartment',
        'appear',
        'appearance',
        'apple',
        'application',
        'apply',
        'appropriate',
        'approval',
        'approve',
        'April',
        'area',
        'argue',
        'argument',
        'arm',
        'army',
        'around',
        'arrange',
        'arrangement',
        'arrest',
        'arrive',
        'arrow',
        'art',
        'article',
        'artificial',
        'artist',
        'artistic',
        'as',
        'ashamed',
        'ask',
        'asleep',
        'at',
        'atmosphere',
        'attack',
        'attention',
        'attract',
        'attractive',
        'August',
        'aunt',
        'autumn',
        'available',
        'avoid',
        'awake',
        'aware',
        'away',
        'awesome',
        'awful',
        'axe'
        ],
    'b' : [
        'baby',
        'back',
        'backwards',
        'bad',
        'badly',
        'badminton',
        'bad-tempered',
        'bag',
        'bake',
        'balance',
        'ball',
        'balloon',
        'band',
        'bank',
        'bar',
        'base',
        'baseball',
        'basic',
        'basis',
        'basket',
        'basketball',
        'bat',
        'bath',
        'bathroom',
        'be',
        'beach',
        'bear',
        'beard',
        'beat',
        'beautiful',
        'beauty',
        'become',
        'bed',
        'bedroom',
        'bee',
        'beef',
        'been',
        'beer',
        'before',
        'begin',
        'beginning',
        'behave',
        'behaviour',
        'behind',
        'belief',
        'believe',
        'bell',
        'belong',
        'below',
        'belt',
        'bend',
        'beneath',
        'benefit',
        'best',
        'bet',
        'better',
        'between',
        'beyond',
        'bicycle',
        'big',
        'bill',
        'billion',
        'bin',
        'bind',
        'biology',
        'bird',
        'birth',
        'birthday',
        'biscuit',
        'bit',
        'bite',
        'bitter',
        'black',
        'blame',
        'block',
        'blood',
        'blow',
        'blue',
        'board',
        'boat',
        'body',
        'boil',
        'bold',
        'bomb',
        'bone',
        'book',
        'boot',
        'border',
        'bored',
        'boring',
        'born',
        'both',
        'bottle',
        'bottom',
        'bow',
        'bowl',
        'box',
        'boy',
        'bra',
        'brain',
        'branch',
        'brave',
        'bread',
        'break',
        'breakfast',
        'breast',
        'breath',
        'breathe',
        'brick',
        'brief',
        'bright',
        'bring',
        'broken',
        'brother',
        'brown',
        'brush',
        'bubble',
        'build',
        'building',
        'bullet',
        'burn'
        ]
    }

'bra'
'breast'

def get():
    return WORD
